{
	"name" : "Localisation sample", # based on belgium files
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Localisation/Europe",
	"depends" : ["account"],
	"init_xml" : [],
	"demo_xml" : ["account_demo.xml"],
	"update_xml" : ["account_pcmn_belgium.xml"],
	"active": True
}
